@@ -72,7 +72,7 @@ void CollectionGeneralPage::init(const Akonadi::Collection &collection)
 
         PimCommon::CollectionTypeUtil collectionUtil;
         const PimCommon::CollectionTypeUtil::IncidencesFor incidencesFor =
-            collectionUtil.incidencesForFromString(QLatin1String(annotations.value(PimCommon::CollectionTypeUtil ::kolabIncidencesFor())));
+            collectionUtil.incidencesForFromString(QLatin1StringView(annotations.value(PimCommon::CollectionTypeUtil ::kolabIncidencesFor())));
         mIncidencesForComboBox = new PimCommon::IncidencesForWidget(this);
         topLayout->addRow(PimCommon::IncidencesForWidget::labelName(), mIncidencesForComboBox);
 
