@@ -44,13 +44,12 @@ public:
         return incidence->accept(*this, incidence);
     }
 
-protected:
+private:
     KODialogManager *mDialogManager = nullptr;
 };
 
 KODialogManager::KODialogManager(CalendarView *mainView)
-    : QObject()
-    , mMainView(mainView)
+    : mMainView(mainView)
 {
 }
 
@@ -151,13 +150,6 @@ void KODialogManager::connectTypeAhead(IncidenceEditorNG::IncidenceDialog *dialo
     }
 }
 
-void KODialogManager::updateSearchDialog()
-{
-    if (mSearchDialog) {
-        mSearchDialog->updateView();
-    }
-}
-
 void KODialogManager::createCategoryEditor()
 {
     if (!mCategoryEditDialog) {
