@@ -86,7 +86,7 @@ void KOGlobals::setHolidays(const QStringList &regions)
     }
 }
 
-QList<KHolidays::HolidayRegion *> KOGlobals::holidays() const
+QList<KHolidays::HolidayRegion *> &KOGlobals::holidays()
 {
     return mHolidayRegions;
 }
