@@ -26,11 +26,6 @@ class QDate;
 
 namespace KOHelper
 {
-/**
-  Returns a nice QColor for text, give the input color &c.
-*/
-KORGANIZERPRIVATE_EXPORT QColor getTextColor(const QColor &c);
-
 /**
   This method returns the proper resource / subresource color for the view.
   @return The resource color for the incidence. If the incidence belongs
@@ -43,16 +38,9 @@ KORGANIZERPRIVATE_EXPORT QColor getTextColor(const QColor &c);
 [[nodiscard]] KORGANIZERPRIVATE_EXPORT QColor resourceColorKnown(const Akonadi::Collection &collection);
 KORGANIZERPRIVATE_EXPORT void setResourceColor(const Akonadi::Collection &collection, const QColor &color);
 
-/**
-  Returns the number of years between the @p start QDate and the @p end QDate
-  (i.e. the difference in the year number of both dates)
-*/
-[[nodiscard]] KORGANIZERPRIVATE_EXPORT int yearDiff(QDate start, QDate end);
-
 /**
   Return true if it's the standard (that is, the current default) calendar.
 */
 [[nodiscard]] KORGANIZERPRIVATE_EXPORT bool isStandardCalendar(Akonadi::Collection::Id id);
 
-KORGANIZERPRIVATE_EXPORT void showSaveIncidenceErrorMsg(QWidget *parent, const KCalendarCore::Incidence::Ptr &incidence);
 }
