@@ -60,7 +60,7 @@ void KCMTodoSummary::load()
     KConfig config(QStringLiteral("kcmtodosummaryrc"));
     KConfigGroup group = config.group(QStringLiteral("Days"));
 
-    int days = group.readEntry("DaysToShow", 7);
+    int const days = group.readEntry("DaysToShow", 7);
     if (days == 1) {
         mDateTodayButton->setChecked(true);
     } else if (days == 31) {
