@@ -43,7 +43,6 @@ public:
     ActionManager *actionManager() override;
     [[nodiscard]] KActionCollection *getActionCollection() const override;
 
-    // void initializePluginActions();
     /**
       Open calendar file from URL. Merge into current calendar, if \a merge is
       true.
@@ -85,8 +84,6 @@ protected Q_SLOTS:
     /** Sets title of window according to filename and modification state */
     void setTitle() override;
 
-    void newMainWindow(const QUrl &);
-
     void slotEditKeys();
 
 protected:
