@@ -36,6 +36,7 @@ namespace Akonadi
 class Item;
 }
 
+class KActionCollection;
 class KConfig;
 class QTabWidget;
 
@@ -91,16 +92,6 @@ public:
         return mAgendaView;
     }
 
-    KOrg::MultiAgendaView *multiAgendaView() const
-    {
-        return mAgendaSideBySideView;
-    }
-
-    KOTodoView *todoView() const
-    {
-        return mTodoView;
-    }
-
     KOrg::MonthView *monthView() const
     {
         return mMonthView;
@@ -126,6 +117,10 @@ public:
         return mRangeMode;
     }
 
+    [[nodiscard]] QAction *viewToAction(const QString &, RangeMode);
+    void viewActionEnable(QObject *);
+    void viewActionEnable(QAction *);
+
 Q_SIGNALS:
     void configChanged();
     void datesSelected(const KCalendarCore::DateList &);
@@ -165,6 +160,8 @@ private Q_SLOTS:
     void removeCalendar(const Akonadi::CollectionCalendar::Ptr &calendar);
 
 private:
+    KActionCollection *getActionCollection();
+    [[nodiscard]] bool isAgendaViewAction(QAction *, KActionCollection *);
     QWidget *widgetForView(KOrg::BaseView *) const;
     QList<KOrg::BaseView *> mViews;
     CalendarView *const mMainView;
@@ -183,6 +180,7 @@ private:
     KOrg::BaseView *mLastEventView = nullptr;
     QTabWidget *mAgendaViewTabs = nullptr;
     int mAgendaViewTabIndex = 0;
+    QAction *mLastViewAction = nullptr;
 
     RangeMode mRangeMode = NO_RANGE;
 };
