@@ -24,12 +24,16 @@ public:
     }
 
     KOPrefs *const prefs;
+
+private:
+    // disable copy ctor
+    KOPrefsPrivate(const KOPrefsPrivate &) = delete;
+    KOPrefsPrivate &operator=(const KOPrefsPrivate &) = delete;
 };
 
 Q_GLOBAL_STATIC(KOPrefsPrivate, sInstance)
 
 KOPrefs::KOPrefs()
-    : KOPrefsBase()
 {
     mEventViewsPrefs = EventViews::PrefsPtr(new EventViews::Prefs(this));
 
@@ -66,7 +70,7 @@ void KOPrefs::usrSetDefaults()
 
 void KOPrefs::usrRead()
 {
-    KConfigGroup timeScaleConfig(config(), QStringLiteral("Timescale"));
+    KConfigGroup const timeScaleConfig(config(), QStringLiteral("Timescale"));
     setTimeScaleTimezones(timeScaleConfig.readEntry("Timescale Timezones", QStringList()));
 
     KConfigSkeleton::usrRead();
@@ -95,7 +99,7 @@ QColor KOPrefs::resourceColorKnown(const QString &cal) const
     return mEventViewsPrefs->resourceColorKnown(cal);
 }
 
-QStringList KOPrefs::timeScaleTimezones() const
+QStringList &KOPrefs::timeScaleTimezones()
 {
     return mTimeScaleTimeZones;
 }
