@@ -33,51 +33,9 @@
 #include <QRadioButton>
 #include <QSpinBox>
 #include <QTimeEdit>
-#include <qwidget.h>
 
 using namespace Korganizer;
 
-namespace KPrefsWidFactory
-{
-KPrefsWid *create(KConfigSkeletonItem *item, QWidget *parent)
-{
-    auto boolItem = dynamic_cast<KConfigSkeleton::ItemBool *>(item);
-    if (boolItem) {
-        return new KPrefsWidBool(boolItem, parent);
-    }
-
-    auto stringItem = dynamic_cast<KConfigSkeleton::ItemString *>(item);
-    if (stringItem) {
-        return new KPrefsWidString(stringItem, parent);
-    }
-
-    auto enumItem = dynamic_cast<KConfigSkeleton::ItemEnum *>(item);
-    if (enumItem) {
-        QList<KConfigSkeleton::ItemEnum::Choice> choices = enumItem->choices();
-        if (choices.isEmpty()) {
-            qCritical() << "Enum has no choices.";
-            return nullptr;
-        } else {
-            auto radios = new KPrefsWidRadios(enumItem, parent);
-            QList<KConfigSkeleton::ItemEnum::Choice>::ConstIterator it;
-            int value = 0;
-            QList<KConfigSkeleton::ItemEnum::Choice>::ConstIterator end(choices.constEnd());
-            for (it = choices.constBegin(); it != end; ++it) {
-                radios->addRadio(value++, (*it).label);
-            }
-            return radios;
-        }
-    }
-
-    auto intItem = dynamic_cast<KConfigSkeleton::ItemInt *>(item);
-    if (intItem) {
-        return new KPrefsWidInt(intItem, parent);
-    }
-
-    return nullptr;
-}
-} // namespace KPrefsWidFactory
-
 QList<QWidget *> KPrefsWid::widgets() const
 {
     return {};
@@ -99,11 +57,11 @@ void KPrefsWidBool::init(QWidget *parent)
 {
     mCheck = new QCheckBox(mItem->label(), parent);
     connect(mCheck, &QCheckBox::clicked, this, &KPrefsWidBool::changed);
-    QString toolTip = mItem->toolTip();
+    const QString toolTip = mItem->toolTip();
     if (!toolTip.isEmpty()) {
         mCheck->setToolTip(toolTip);
     }
-    QString whatsThis = mItem->whatsThis();
+    const QString whatsThis = mItem->whatsThis();
     if (!whatsThis.isEmpty()) {
         mCheck->setWhatsThis(whatsThis);
     }
@@ -124,13 +82,6 @@ QCheckBox *KPrefsWidBool::checkBox()
     return mCheck;
 }
 
-QList<QWidget *> KPrefsWidBool::widgets() const
-{
-    QList<QWidget *> widgets;
-    widgets.append(mCheck);
-    return widgets;
-}
-
 KPrefsWidInt::KPrefsWidInt(KConfigSkeleton::ItemInt *item, QWidget *parent)
     : mItem(item)
 {
@@ -144,12 +95,12 @@ KPrefsWidInt::KPrefsWidInt(KConfigSkeleton::ItemInt *item, QWidget *parent)
     }
     connect(mSpin, &QSpinBox::valueChanged, this, &KPrefsWidInt::changed);
     mLabel->setBuddy(mSpin);
-    QString toolTip = mItem->toolTip();
+    const QString toolTip = mItem->toolTip();
     if (!toolTip.isEmpty()) {
         mLabel->setToolTip(toolTip);
         mSpin->setToolTip(toolTip);
     }
-    QString whatsThis = mItem->whatsThis();
+    const QString whatsThis = mItem->whatsThis();
     if (!whatsThis.isEmpty()) {
         mLabel->setWhatsThis(whatsThis);
         mSpin->setWhatsThis(whatsThis);
@@ -176,14 +127,6 @@ QSpinBox *KPrefsWidInt::spinBox()
     return mSpin;
 }
 
-QList<QWidget *> KPrefsWidInt::widgets() const
-{
-    QList<QWidget *> widgets;
-    widgets.append(mLabel);
-    widgets.append(mSpin);
-    return widgets;
-}
-
 KPrefsWidColor::KPrefsWidColor(KConfigSkeleton::ItemColor *item, QWidget *parent)
     : mItem(item)
 {
@@ -191,11 +134,11 @@ KPrefsWidColor::KPrefsWidColor(KConfigSkeleton::ItemColor *item, QWidget *parent
     connect(mButton, &KColorButton::changed, this, &KPrefsWidColor::changed);
     mLabel = new QLabel(mItem->label() + QLatin1Char(':'), parent);
     mLabel->setBuddy(mButton);
-    QString toolTip = mItem->toolTip();
+    const QString toolTip = mItem->toolTip();
     if (!toolTip.isEmpty()) {
         mButton->setToolTip(toolTip);
     }
-    QString whatsThis = mItem->whatsThis();
+    const QString whatsThis = mItem->whatsThis();
     if (!whatsThis.isEmpty()) {
         mButton->setWhatsThis(whatsThis);
     }
@@ -233,12 +176,12 @@ KPrefsWidFont::KPrefsWidFont(KConfigSkeleton::ItemFont *item, QWidget *parent, c
 
     mButton = new QPushButton(i18nc("@action:button", "Choose…"), parent);
     connect(mButton, &QPushButton::clicked, this, &Korganizer::KPrefsWidFont::selectFont);
-    QString toolTip = mItem->toolTip();
+    const QString toolTip = mItem->toolTip();
     if (!toolTip.isEmpty()) {
         mPreview->setToolTip(toolTip);
         mButton->setToolTip(toolTip);
     }
-    QString whatsThis = mItem->whatsThis();
+    const QString whatsThis = mItem->whatsThis();
     if (!whatsThis.isEmpty()) {
         mPreview->setWhatsThis(whatsThis);
         mButton->setWhatsThis(whatsThis);
@@ -276,7 +219,7 @@ void KPrefsWidFont::selectFont()
 {
 #ifndef QT_NO_FONTDIALOG
     bool ok;
-    QFont myFont = QFontDialog::getFont(&ok, mPreview->font());
+    const QFont myFont = QFontDialog::getFont(&ok, mPreview->font());
     if (ok) {
         mPreview->setFont(myFont);
         Q_EMIT changed();
@@ -292,11 +235,11 @@ KPrefsWidTime::KPrefsWidTime(KConfigSkeleton::ItemDateTime *item, QWidget *paren
     mLabel->setBuddy(mTimeEdit);
     connect(mTimeEdit, &KTimeComboBox::timeEdited, this, &KPrefsWidTime::changed);
     connect(mTimeEdit, &KTimeComboBox::timeEntered, this, &KPrefsWidTime::changed);
-    QString toolTip = mItem->toolTip();
+    const QString toolTip = mItem->toolTip();
     if (!toolTip.isEmpty()) {
         mTimeEdit->setToolTip(toolTip);
     }
-    QString whatsThis = mItem->whatsThis();
+    const QString whatsThis = mItem->whatsThis();
     if (!whatsThis.isEmpty()) {
         mTimeEdit->setWhatsThis(whatsThis);
     }
@@ -340,11 +283,11 @@ KPrefsWidDuration::KPrefsWidDuration(KConfigSkeleton::ItemDateTime *item, const
     mTimeEdit->setMinimumTime(QTime(0, 1)); // [1 min]
     mTimeEdit->setMaximumTime(QTime(24, 0)); // [24 hr]
     connect(mTimeEdit, &QTimeEdit::timeChanged, this, &KPrefsWidDuration::changed);
-    QString toolTip = mItem->toolTip();
+    const QString toolTip = mItem->toolTip();
     if (!toolTip.isEmpty()) {
         mTimeEdit->setToolTip(toolTip);
     }
-    QString whatsThis = mItem->whatsThis();
+    const QString whatsThis = mItem->whatsThis();
     if (!whatsThis.isEmpty()) {
         mTimeEdit->setWhatsThis(whatsThis);
     }
@@ -379,11 +322,11 @@ KPrefsWidDate::KPrefsWidDate(KConfigSkeleton::ItemDateTime *item, QWidget *paren
     mDateEdit = new KDateComboBox(parent);
     mLabel->setBuddy(mDateEdit);
     connect(mDateEdit, &KDateComboBox::dateEdited, this, &KPrefsWidDate::changed);
-    QString toolTip = mItem->toolTip();
+    const QString toolTip = mItem->toolTip();
     if (!toolTip.isEmpty()) {
         mDateEdit->setToolTip(toolTip);
     }
-    QString whatsThis = mItem->whatsThis();
+    const QString whatsThis = mItem->whatsThis();
     if (!whatsThis.isEmpty()) {
         mDateEdit->setWhatsThis(whatsThis);
     }
@@ -412,11 +355,6 @@ QLabel *KPrefsWidDate::label()
     return mLabel;
 }
 
-KDateComboBox *KPrefsWidDate::dateEdit()
-{
-    return mDateEdit;
-}
-
 KPrefsWidRadios::KPrefsWidRadios(KConfigSkeleton::ItemEnum *item, QWidget *parent)
     : mItem(item)
 {
@@ -459,13 +397,6 @@ void KPrefsWidRadios::writeConfig()
     mItem->setValue(mGroup->checkedId());
 }
 
-QList<QWidget *> KPrefsWidRadios::widgets() const
-{
-    QList<QWidget *> w;
-    w.append(mBox);
-    return w;
-}
-
 KPrefsWidCombo::KPrefsWidCombo(KConfigSkeleton::ItemEnum *item, QWidget *parent)
     : mItem(item)
 {
@@ -473,12 +404,12 @@ KPrefsWidCombo::KPrefsWidCombo(KConfigSkeleton::ItemEnum *item, QWidget *parent)
     mCombo = new KComboBox(parent);
     connect(mCombo, &KComboBox::activated, this, &KPrefsWidCombo::changed);
     mLabel->setBuddy(mCombo);
-    QString toolTip = mItem->toolTip();
+    const QString toolTip = mItem->toolTip();
     if (!toolTip.isEmpty()) {
         mLabel->setToolTip(toolTip);
         mCombo->setToolTip(toolTip);
     }
-    QString whatsThis = mItem->whatsThis();
+    const QString whatsThis = mItem->whatsThis();
     if (!whatsThis.isEmpty()) {
         mLabel->setWhatsThis(whatsThis);
         mCombo->setWhatsThis(whatsThis);
@@ -497,13 +428,6 @@ void KPrefsWidCombo::writeConfig()
     mItem->setValue(mCombo->currentIndex());
 }
 
-QList<QWidget *> KPrefsWidCombo::widgets() const
-{
-    QList<QWidget *> w;
-    w.append(mCombo);
-    return w;
-}
-
 KComboBox *KPrefsWidCombo::comboBox()
 {
     return mCombo;
@@ -522,11 +446,11 @@ KPrefsWidString::KPrefsWidString(KConfigSkeleton::ItemString *item, QWidget *par
     mLabel->setBuddy(mEdit);
     connect(mEdit, &KLineEdit::textChanged, this, &KPrefsWidString::changed);
     mEdit->setEchoMode(echomode);
-    QString toolTip = mItem->toolTip();
+    const QString toolTip = mItem->toolTip();
     if (!toolTip.isEmpty()) {
         mEdit->setToolTip(toolTip);
     }
-    QString whatsThis = mItem->whatsThis();
+    const QString whatsThis = mItem->whatsThis();
     if (!whatsThis.isEmpty()) {
         mEdit->setWhatsThis(whatsThis);
     }
@@ -554,14 +478,6 @@ KLineEdit *KPrefsWidString::lineEdit()
     return mEdit;
 }
 
-QList<QWidget *> KPrefsWidString::widgets() const
-{
-    QList<QWidget *> widgets;
-    widgets.append(mLabel);
-    widgets.append(mEdit);
-    return widgets;
-}
-
 KPrefsWidPath::KPrefsWidPath(KConfigSkeleton::ItemPath *item, QWidget *parent, const QString &filter, KFile::Modes mode)
     : mItem(item)
 {
@@ -571,11 +487,11 @@ KPrefsWidPath::KPrefsWidPath(KConfigSkeleton::ItemPath *item, QWidget *parent, c
     mURLRequester->setMode(mode);
     mURLRequester->setNameFilter(filter);
     connect(mURLRequester, &KUrlRequester::textChanged, this, &KPrefsWidPath::changed);
-    QString toolTip = mItem->toolTip();
+    const QString toolTip = mItem->toolTip();
     if (!toolTip.isEmpty()) {
         mURLRequester->setToolTip(toolTip);
     }
-    QString whatsThis = mItem->whatsThis();
+    const QString whatsThis = mItem->whatsThis();
     if (!whatsThis.isEmpty()) {
         mURLRequester->setWhatsThis(whatsThis);
     }
@@ -603,14 +519,6 @@ KUrlRequester *KPrefsWidPath::urlRequester()
     return mURLRequester;
 }
 
-QList<QWidget *> KPrefsWidPath::widgets() const
-{
-    QList<QWidget *> widgets;
-    widgets.append(mLabel);
-    widgets.append(mURLRequester);
-    return widgets;
-}
-
 KPrefsWidManager::KPrefsWidManager(KConfigSkeleton *prefs)
     : mPrefs(prefs)
 {
@@ -655,13 +563,6 @@ KPrefsWidDuration *KPrefsWidManager::addWidDuration(KConfigSkeleton::ItemDateTim
     return w;
 }
 
-KPrefsWidDate *KPrefsWidManager::addWidDate(KConfigSkeleton::ItemDateTime *item, QWidget *parent)
-{
-    auto w = new KPrefsWidDate(item, parent);
-    addWid(w);
-    return w;
-}
-
 KPrefsWidColor *KPrefsWidManager::addWidColor(KConfigSkeleton::ItemColor *item, QWidget *parent)
 {
     auto w = new KPrefsWidColor(item, parent);
@@ -675,7 +576,7 @@ KPrefsWidRadios *KPrefsWidManager::addWidRadios(KConfigSkeleton::ItemEnum *item,
     QList<KConfigSkeleton::ItemEnum::Choice> choices;
     choices = item->choices();
     QList<KConfigSkeleton::ItemEnum::Choice>::ConstIterator it;
-    QList<KConfigSkeleton::ItemEnum::Choice>::ConstIterator end(choices.constEnd());
+    const QList<KConfigSkeleton::ItemEnum::Choice>::ConstIterator end(choices.constEnd());
     int value = 0;
     for (it = choices.constBegin(); it != end; ++it) {
         w->addRadio(value++, (*it).label, (*it).toolTip, (*it).whatsThis);
@@ -689,7 +590,7 @@ KPrefsWidCombo *KPrefsWidManager::addWidCombo(KConfigSkeleton::ItemEnum *item, Q
     auto w = new KPrefsWidCombo(item, parent);
     QList<KConfigSkeleton::ItemEnum::Choice> choices;
     choices = item->choices();
-    QList<KConfigSkeleton::ItemEnum::Choice>::ConstIterator end(choices.constEnd());
+    const QList<KConfigSkeleton::ItemEnum::Choice>::ConstIterator end(choices.constEnd());
     for (QList<KConfigSkeleton::ItemEnum::Choice>::ConstIterator it = choices.constBegin(); it != end; ++it) {
         w->comboBox()->addItem((*it).label);
     }
@@ -711,13 +612,6 @@ KPrefsWidPath *KPrefsWidManager::addWidPath(KConfigSkeleton::ItemPath *item, QWi
     return w;
 }
 
-KPrefsWidString *KPrefsWidManager::addWidPassword(KConfigSkeleton::ItemString *item, QWidget *parent)
-{
-    auto w = new KPrefsWidString(item, parent, KLineEdit::Password);
-    addWid(w);
-    return w;
-}
-
 KPrefsWidFont *KPrefsWidManager::addWidFont(KConfigSkeleton::ItemFont *item, QWidget *parent, const QString &sampleText)
 {
     auto w = new KPrefsWidFont(item, parent, sampleText);
@@ -734,7 +628,7 @@ KPrefsWidInt *KPrefsWidManager::addWidInt(KConfigSkeleton::ItemInt *item, QWidge
 
 void KPrefsWidManager::setWidDefaults()
 {
-    bool tmp = mPrefs->useDefaults(true);
+    const bool tmp = mPrefs->useDefaults(true);
     readWidConfig();
     mPrefs->useDefaults(tmp);
 }
@@ -774,62 +668,6 @@ KPrefsDialog::KPrefsDialog(KConfigSkeleton *prefs, QWidget *parent, bool modal)
 
 KPrefsDialog::~KPrefsDialog() = default;
 
-void KPrefsDialog::autoCreate()
-{
-    KConfigSkeletonItem::List items = prefs()->items();
-
-    QMap<QString, QWidget *> mGroupPages;
-    QMap<QString, QGridLayout *> mGroupLayouts;
-    QMap<QString, int> mCurrentRows;
-
-    KConfigSkeletonItem::List::ConstIterator it;
-    for (it = items.constBegin(); it != items.constEnd(); ++it) {
-        QString group = (*it)->group();
-
-        QWidget *page = nullptr;
-        QGridLayout *layout = nullptr;
-        int currentRow;
-        if (!mGroupPages.contains(group)) {
-            page = new QWidget(this);
-            addPage(page, group);
-            layout = new QGridLayout(page);
-            mGroupPages.insert(group, page);
-            mGroupLayouts.insert(group, layout);
-            currentRow = 0;
-            mCurrentRows.insert(group, currentRow);
-        } else {
-            page = mGroupPages[group];
-            layout = mGroupLayouts[group];
-            currentRow = mCurrentRows[group];
-        }
-
-        KPrefsWid *wid = KPrefsWidFactory::create(*it, page);
-
-        if (wid) {
-            QList<QWidget *> widgets = wid->widgets();
-            if (widgets.count() == 1) {
-                layout->addWidget(widgets[0], currentRow, currentRow, 0, 1);
-            } else if (widgets.count() == 2) {
-                layout->addWidget(widgets[0], currentRow, 0);
-                layout->addWidget(widgets[1], currentRow, 1);
-            } else {
-                qCritical() << "More widgets than expected:" << widgets.count();
-            }
-
-            if ((*it)->isImmutable()) {
-                QList<QWidget *>::Iterator it2;
-                for (it2 = widgets.begin(); it2 != widgets.end(); ++it2) {
-                    (*it2)->setEnabled(false);
-                }
-            }
-            addWid(wid);
-            mCurrentRows.insert(group, ++currentRow);
-        }
-    }
-
-    readConfig();
-}
-
 void KPrefsDialog::setDefaults()
 {
     setWidDefaults();
@@ -864,8 +702,9 @@ void KPrefsDialog::slotOk()
 void KPrefsDialog::slotDefault()
 {
     if (KMessageBox::warningContinueCancel(this,
-                                           i18n("You are about to set all preferences to default values. "
-                                                "All custom modifications will be lost."),
+                                           i18nc("@info",
+                                                 "You are about to set all preferences to default values. "
+                                                 "All custom modifications will be lost."),
                                            i18nc("@title:window", "Setting Default Preferences"),
                                            KGuiItem(i18nc("@action:button", "Reset to Defaults")))
         == KMessageBox::Continue) {
