@@ -15,7 +15,7 @@
 
 int main(int argc, char **argv)
 {
-    QApplication app(argc, argv);
+    const QApplication app(argc, argv);
     QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
